@@ -1,13 +1,19 @@
 """
 Plotting of input data and calculated database quantities
 """
+import warnings
+from collections import OrderedDict
+
+from cycler import cycler
+import matplotlib.pyplot as plt
+import matplotlib.lines as mlines
 import numpy as np
 import tinydb
-from collections import OrderedDict
 from pycalphad import Model, calculate, equilibrium, variables as v
 from pycalphad.plot.utils import phase_legend
 from pycalphad.plot.eqplot import eqplot, _map_coord_to_variable, unpack_condition
 
+from espei.utils import bib_marker_map
 from espei.core_utils import get_data, get_samples, list_to_tuple, \
     endmembers_from_interaction, build_sitefractions
 
@@ -25,49 +31,279 @@ plot_mapping = {
 }
 
 
-def plot_parameters(dbf, comps, phase_name, configuration, symmetry, datasets=None):
+def plot_parameters(dbf, comps, phase_name, configuration, symmetry, datasets=None, fig=None, require_data=True):
+    """
+    Plot parameters of interest compared with data in subplots of a single figure
+
+    Parameters
+    ----------
+    dbf : Database
+        pycalphad thermodynamic database containing the relevant parameters.
+    comps : list
+        Names of components to consider in the calculation.
+    phase_name : str
+        Name of the considered phase phase
+    configuration : tuple
+        Sublattice configuration to plot, such as ('CU', 'CU') or (('CU', 'MG'), 'CU')
+    symmetry : list
+        List of lists containing indices of symmetric sublattices e.g. [[0, 1], [2, 3]]
+    datasets : PickleableTinyDB
+        ESPEI datasets to compare against. If None, nothing is plotted.
+    fig : matplotlib.Figure
+        Figure to create with axes as subplots.
+    require_data : bool
+        If True, plot parameters that have data corresponding data. Defaults to
+        True. Will raise an error for non-interaction configurations.
+
+    Returns
+    -------
+    None
+
+    Examples
+    --------
+    # plot the LAVES_C15 (Cu)(Mg) endmember
+    >>> plot_parameters(dbf, ['CU', 'MG'], 'LAVES_C15', ('CU', 'MG'), symmetry=None, datasets=datasets)
+    # plot the mixing interaction in the first sublattice
+    >>> plot_parameters(dbf, ['CU', 'MG'], 'LAVES_C15', (('CU', 'MG'), 'MG'), symmetry=None, datasets=datasets)
+
+    """
     em_plots = [('T', 'CPM'), ('T', 'CPM_FORM'), ('T', 'SM'), ('T', 'SM_FORM'),
                 ('T', 'HM'), ('T', 'HM_FORM')]
     mix_plots = [('Z', 'HM_FORM'), ('Z', 'HM_MIX'), ('Z', 'SM_MIX')]
     comps = sorted(comps)
     mod = Model(dbf, comps, phase_name)
     # This is for computing properties of formation
-    mod_norefstate = Model(dbf, comps, phase_name, parameters={'GHSER'+c.upper(): 0 for c in comps})
+    mod_norefstate = Model(dbf, comps, phase_name, parameters={'GHSER'+(c.upper()*2)[:2]: 0 for c in comps})
     # Is this an interaction parameter or endmember?
     if any([isinstance(conf, list) or isinstance(conf, tuple) for conf in configuration]):
         plots = mix_plots
     else:
         plots = em_plots
-    for x_val, y_val in plots:
-        if datasets is not None:
-            if y_val.endswith('_MIX'):
-                desired_props = [y_val.split('_')[0]+'_FORM', y_val]
-            else:
-                desired_props = [y_val]
-            desired_data = get_data(comps, phase_name, configuration, symmetry, datasets, desired_props)
-        else:
-            desired_data = []
-        if len(desired_data) == 0:
-            continue
+
+    # filter which parameters to plot by the data that exists
+    if require_data and datasets is not None:
+        filtered_plots = []
+        for x_val, y_val in plots:
+            desired_props = [y_val.split('_')[0]+'_FORM', y_val] if y_val.endswith('_MIX') else [y_val]
+            data = get_data(comps, phase_name, configuration, symmetry, datasets, desired_props)
+            if len(data) > 0:
+                filtered_plots.append((x_val, y_val, data))
+    elif require_data:
+        raise ValueError('Plots require datasets, but no datasets were passed.')
+    elif plots == em_plots and not require_data:
+        # How we treat temperature dependence is ambiguous when there is no data, so we raise an error
+        raise ValueError('The "require_data=False" option is not supported for non-mixing configurations.')
+    elif datasets is not None:
+        filtered_plots = []
+        for x_val, y_val in plots:
+            desired_props = [y_val.split('_')[0]+'_FORM', y_val] if y_val.endswith('_MIX') else [y_val]
+            data = get_data(comps, phase_name, configuration, symmetry, datasets, desired_props)
+            filtered_plots.append((x_val, y_val, data))
+    else:
+        filtered_plots = [(x_val, y_val, []) for x_val, y_val in plots]
+
+    num_plots = len(filtered_plots)
+    if num_plots == 0:
+        return
+    if not fig:
+        fig = plt.figure(figsize=plt.figaspect(num_plots))
+
+    # plot them
+    for i, (x_val, y_val, data) in enumerate(filtered_plots):
         if y_val.endswith('_FORM'):
-            _compare_data_to_parameters(dbf, comps, phase_name, desired_data, mod_norefstate, configuration, x_val, y_val)
+            ax = fig.add_subplot(num_plots, 1, i+1)
+            ax = _compare_data_to_parameters(dbf, comps, phase_name, data, mod_norefstate, configuration, x_val, y_val, ax=ax)
         else:
-            _compare_data_to_parameters(dbf, comps, phase_name, desired_data, mod, configuration, x_val, y_val)
+            ax = fig.add_subplot(num_plots, 1, i+1)
+            ax = _compare_data_to_parameters(dbf, comps, phase_name, data, mod, configuration, x_val, y_val, ax=ax)
 
 
-
-def dataplot(eq, datasets, ax=None):
+def dataplot(comps, phases, conds, datasets, ax=None, plot_kwargs=None):
     """
-    Plot datapoints corresponding to the components and phases in the eq Dataset
+    Plot datapoints corresponding to the components, phases, and conditions.
+
+
+    Parameters
+    ----------
+    comps : list
+        Names of components to consider in the calculation.
+    phases : []
+        Names of phases to consider in the calculation.
+    conds : dict
+        Maps StateVariables to values and/or iterables of values.
+    datasets : PickleableTinyDB
+    ax : matplotlib.Axes
+        Default axes used if not specified.
+    plot_kwargs : dict
+        Additional keyword arguments to pass to the matplotlib plot function
+
+    Returns
+    -------
+    matplotlib.Axes
+        A plot of phase equilibria points as a figure
+
+    Examples
+    --------
+
+    >>> from espei.datasets import load_datasets, recursive_glob
+    >>> from espei.plot import dataplot
+    >>> datasets = load_datasets(recursive_glob('.', '*.json'))
+    >>> my_phases = ['BCC_A2', 'CUMG2', 'FCC_A1', 'LAVES_C15', 'LIQUID']
+    >>> my_components = ['CU', 'MG' 'VA']
+    >>> conditions = {v.P: 101325, v.T: 1000, v.X('MG'): (0, 1, 0.01)}
+    >>> dataplot(my_components, my_phases, conditions, datasets)
+
+    """
+    indep_comps = [key for key, value in conds.items() if isinstance(key, v.Composition) and len(np.atleast_1d(value)) > 1]
+    indep_pots = [key for key, value in conds.items() if ((key == v.T) or (key == v.P)) and len(np.atleast_1d(value)) > 1]
+    plot_kwargs = plot_kwargs or {}
+    phases = sorted(phases)
+
+    # determine what the type of plot will be
+    if len(indep_comps) == 1 and len(indep_pots) == 1:
+        projection = None
+    elif len(indep_comps) == 2 and len(indep_pots) == 0:
+        # TODO: support isotherm plotting
+        raise NotImplementedError('Triangular plotting is not yet implemented')
+        projection = 'triangular'
+    else:
+        raise ValueError('The eqplot projection is not defined and cannot be autodetected. There are {} independent compositions and {} indepedent potentials.'.format(len(indep_comps), len(indep_pots)))
+
+    if projection is None:
+        x = indep_comps[0].species
+        y = indep_pots[0]
+
+    # set up plot if not done already
+    if ax is None:
+        ax = plt.gca(projection=projection)
+        box = ax.get_position()
+        ax.set_position([box.x0, box.y0, box.width * 0.8, box.height])
+        ax.tick_params(axis='both', which='major', labelsize=14)
+        ax.grid(True)
+        plot_title = '-'.join([component.title() for component in sorted(comps) if component != 'VA'])
+        ax.set_title(plot_title, fontsize=20)
+        ax.set_xlabel('X({})'.format(x), labelpad=15, fontsize=20)
+        ax.set_ylabel(plot_mapping.get(str(y), y), fontsize=20)
+        ax.set_xlim((0, 1))
+
+    # handle plotting kwargs
+    scatter_kwargs = {'markersize': 6, 'markeredgewidth': 0.2}
+    # raise warnings if any of the aliased versions of the default values are used
+    possible_aliases = [('markersize', 'ms'), ('markeredgewidth', 'mew')]
+    for actual_arg, aliased_arg in possible_aliases:
+        if aliased_arg in plot_kwargs:
+            warnings.warn("'{0}' passed as plotting keyword argument to dataplot, but the alias '{1}' is already set to '{2}'. Use the full version of the keyword argument '{1}' to override the default.".format(aliased_arg, actual_arg, scatter_kwargs.get(actual_arg)))
+    scatter_kwargs.update(plot_kwargs)
+
+    plots = [('ZPF', 'T')]
+    for output, y in plots:
+        # TODO: used to include VA. Should this be added by default. Can't determine presence of VA in eq.
+        # Techincally, VA should not be present in any phase equilibria.
+        desired_data = datasets.search((tinydb.where('output') == output) &
+                                       (tinydb.where('components').test(lambda x: set(x).issubset(comps + ['VA']))) &
+                                       (tinydb.where('phases').test(lambda x: len(set(phases).intersection(x)) > 0)))
+
+        # get all the possible references from the data and create the bibliography map
+        # TODO: explore building tielines from multiphase equilibria. Should we do this?
+        bib_reference_keys = sorted(list({entry['reference'] for entry in desired_data}))
+        symbol_map = bib_marker_map(bib_reference_keys)
+
+        # The above handled the phases as in the equilibrium, but there may be
+        # phases that are in the datasets but not in the equilibrium diagram that
+        # we would like to plot point for (they need color maps).
+        # To keep consistent colors with the equilibrium diagram, we will append
+        # the new phases from the datasets to the existing phases in the equilibrium
+        # calculation.
+        data_phases = set()
+        for entry in desired_data:
+            data_phases.update(set(entry['phases']))
+        new_phases = sorted(list(data_phases.difference(set(phases))))
+        phases.extend(new_phases)
+        legend_handles, phase_color_map = phase_legend(phases)
+
+        # now we will add the symbols for the references to the legend handles
+        for ref_key in bib_reference_keys:
+            mark = symbol_map[ref_key]['markers']
+            # The legend marker edge width appears smaller than in the plot.
+            # We will add this small hack to increase the width in the legend only.
+            legend_kwargs = scatter_kwargs.copy()
+            legend_kwargs['markeredgewidth'] *= 5
+            legend_handles.append(mlines.Line2D([], [], linestyle='',
+                                                color='black', markeredgecolor='black',
+                                                label=symbol_map[ref_key]['formatted'],
+                                                fillstyle=mark['fillstyle'],
+                                                marker=mark['marker'],
+                                                **legend_kwargs))
+
+        # finally, add the completed legend
+        ax.legend(handles=legend_handles, loc='center left', bbox_to_anchor=(1, 0.5))
+
+        # TODO: There are lot of ways this could break in multi-component situations
+
+        for data in desired_data:
+            payload = data['values']
+            # TODO: Add broadcast_conditions support
+            # Repeat the temperature (or whatever variable) vector to align with the unraveled data
+            temp_repeats = np.zeros(len(np.atleast_1d(data['conditions'][y])), dtype=np.int)
+            for idx, p in enumerate(payload):
+                temp_repeats[idx] = len(p)
+            temps_ravelled = np.repeat(data['conditions'][y], temp_repeats)
+            payload_ravelled = []
+            phases_ravelled = []
+            comps_ravelled = []
+            symbols_ravelled = []
+            # TODO: Fix to only include equilibria listed in 'phases'
+            for p in payload:
+                markers = symbol_map[data['reference']]['markers']
+                fill_sym_tuple = (markers['fillstyle'], markers['marker'])
+                symbols_ravelled.extend([fill_sym_tuple] * len(p))
+                payload_ravelled.extend(p)
+            for rp in payload_ravelled:
+                phases_ravelled.append(rp[0])
+                comp_dict = dict(zip([x.upper() for x in rp[1]], rp[2]))
+                dependent_comp = list(set(comps) - set(comp_dict.keys()) - set(['VA']))
+                if len(dependent_comp) > 1:
+                    raise ValueError('Dependent components greater than one')
+                elif len(dependent_comp) == 1:
+                    dependent_comp = dependent_comp[0]
+                    # TODO: Assuming N=1
+                    comp_dict[dependent_comp] = 1 - sum(np.array(list(comp_dict.values()), dtype=np.float))
+                chosen_comp_value = comp_dict[x]
+                comps_ravelled.append(chosen_comp_value)
+            symbols_ravelled = np.array(symbols_ravelled)
+            comps_ravelled = np.array(comps_ravelled)
+            temps_ravelled = np.array(temps_ravelled)
+            phases_ravelled = np.array(phases_ravelled)
+            # We can't pass an array of markers to scatter, sadly
+            for fill_sym in symbols_ravelled:
+                # fill_sym is a tuple of ('fillstyle', 'marker')
+                selected = np.all(symbols_ravelled == fill_sym, axis=1)
+                # ax.plot does not seem to be able to take a list of hex values
+                # for colors in the same was as ax.scatter. To get around this,
+                # we'll use the set_prop_cycler for each plot cycle
+                phase_colors = [phase_color_map[x] for x in phases_ravelled[selected]]
+                ax.set_prop_cycle(cycler('color', phase_colors))
+                ax.plot(comps_ravelled[selected], temps_ravelled[selected],
+                        fillstyle=fill_sym[0], marker=fill_sym[1], linestyle='',
+                        **scatter_kwargs)
+    return ax
+
+
+def eqdataplot(eq, datasets, ax=None, plot_kwargs=None):
+    """
+    Plot datapoints corresponding to the components and phases in the eq Dataset.
+    A convenience function for dataplot.
 
     Parameters
     ----------
     eq : xarray.Dataset
         Result of equilibrium calculation.
-    datasets : TinyDB
+    datasets : PickleableTinyDB
         Database of phase equilibria datasets
     ax : matplotlib.Axes
         Default axes used if not specified.
+    plot_kwargs : dict
+        Keyword arguments to pass to dataplot
 
     Returns
     -------
@@ -84,103 +320,19 @@ def dataplot(eq, datasets, ax=None):
     >>> my_phases = list(dbf.phases.keys())
     >>> eq = equilibrium(dbf, ['CU', 'MG', 'VA'], my_phases, {v.P: 101325, v.T: 1000, v.X('MG'): (0, 1, 0.01)})
     >>> ax = eqplot(eq)
-    >>> ax = dataplot(eq, datasets, ax=ax)
+    >>> ax = eqdataplot(eq, datasets, ax=ax)
 
     """
     # TODO: support reference legend
     conds = OrderedDict([(_map_coord_to_variable(key), unpack_condition(np.asarray(value)))
                          for key, value in sorted(eq.coords.items(), key=str)
                          if (key == 'T') or (key == 'P') or (key.startswith('X_'))])
-    indep_comps = sorted([key for key, value in conds.items() if isinstance(key, v.Composition) and len(value) > 1], key=str)
-    indep_pots = [key for key, value in conds.items() if ((key == v.T) or (key == v.P)) and len(value) > 1]
-
-    # determine what the type of plot will be
-    if len(indep_comps) == 1 and len(indep_pots) == 1:
-        projection = None
-    elif len(indep_comps) == 2 and len(indep_pots) == 0:
-        # TODO: support isotherm plotting
-        raise NotImplementedError('Triangular plotting is not yet implemented')
-        projection = 'triangular'
-    else:
-        raise ValueError('The eqplot projection is not defined and cannot be autodetected. There are {} independent compositions and {} indepedent potentials.'.format(len(indep_comps), len(indep_pots)))
-
-    if projection is None:
-        x = indep_comps[0].species
-        y = indep_pots[0]
 
     phases = list(map(str, sorted(set(np.array(eq.Phase.values.ravel(), dtype='U')) - {''}, key=str)))
     comps = list(map(str, sorted(np.array(eq.coords['component'].values, dtype='U'), key=str)))
 
-    # set up plot if not done already
-    if ax is None:
-        import matplotlib.pyplot as plt
-        ax = plt.gca(projection=projection)
-        ax.set_xlabel('X({})'.format(x))
-        ax.set_ylabel(y)
-        ax.set_xlim((0, 1))
+    ax = dataplot(comps, phases, conds, datasets, ax=ax, plot_kwargs=plot_kwargs)
 
-    plots = [('ZPF', 'T')]
-    for output, y in plots:
-        # TODO: used to include VA. Should this be added by default. Can't determine presence of VA in eq.
-        # Techincally, VA should not be present in any phase equilibria.
-        desired_data = datasets.search((tinydb.where('output') == output) &
-                                       (tinydb.where('components').test(lambda x: set(x).issubset(comps + ['VA']))) &
-                                       (tinydb.where('phases').test(lambda x: len(set(phases).intersection(x)) > 0)))
-
-        # The above handled the phases as in the equilibrium, but there may be
-        # phases that are in the datasets but not in the equilibrium diagram that
-        # we would like to plot point for (they need color maps).
-        # To keep consistent colors with the equilibrium diagram, we will append
-        # the new phases from the datasets to the existing phases in the equilibrium
-        # calculation.
-        data_phases = set()
-        for entry in desired_data:
-            data_phases.update(set(entry['phases']))
-        new_phases = sorted(list(data_phases.difference(set(phases))))
-        phases.extend(new_phases)
-        legend_handles, phase_color_map = phase_legend(phases)
-        ax.legend(handles=legend_handles, loc='center left', bbox_to_anchor=(1, 0.5))
-
-        # TODO: There are lot of ways this could break in multi-component situations
-
-        symbol_map = {1: "o", 2: "s", 3: "^"}
-        for data in desired_data:
-            payload = data['values']
-            # TODO: Add broadcast_conditions support
-            # Repeat the temperature (or whatever variable) vector to align with the unraveled data
-            temp_repeats = np.zeros(len(np.atleast_1d(data['conditions'][y])), dtype=np.int)
-            for idx, p in enumerate(payload):
-                temp_repeats[idx] = len(p)
-            temps_ravelled = np.repeat(data['conditions'][y], temp_repeats)
-            payload_ravelled = []
-            phases_ravelled = []
-            comps_ravelled = []
-            symbols_ravelled = []
-            # TODO: Fix to only include equilibria listed in 'phases'
-            for p in payload:
-                symbols_ravelled.extend([symbol_map[len(p)]] * len(p))
-                payload_ravelled.extend(p)
-            for rp in payload_ravelled:
-                phases_ravelled.append(rp[0])
-                comp_dict = dict(zip([x.upper() for x in rp[1]], rp[2]))
-                dependent_comp = list(set(comps) - set(comp_dict.keys()))
-                if len(dependent_comp) > 1:
-                    raise ValueError('Dependent components greater than one')
-                elif len(dependent_comp) == 1:
-                    dependent_comp = dependent_comp[0]
-                    # TODO: Assuming N=1
-                    comp_dict[dependent_comp] = 1 - sum(np.array(list(comp_dict.values()), dtype=np.float))
-                chosen_comp_value = comp_dict[x]
-                comps_ravelled.append(chosen_comp_value)
-            symbols_ravelled = np.array(symbols_ravelled)
-            comps_ravelled = np.array(comps_ravelled)
-            temps_ravelled = np.array(temps_ravelled)
-            phases_ravelled = np.array(phases_ravelled)
-            # We can't pass an array of markers to scatter, sadly
-            for sym in symbols_ravelled:
-                selected = symbols_ravelled == sym
-                ax.scatter(comps_ravelled[selected], temps_ravelled[selected], marker=sym, s=100,
-                           c='none', edgecolors=[phase_color_map[x] for x in phases_ravelled[selected]])
     return ax
 
 
@@ -199,7 +351,7 @@ def multiplot(dbf, comps, phases, conds, datasets, eq_kwargs=None, plot_kwargs=N
         Names of phases to consider in the calculation.
     conds : dict
         Maps StateVariables to values and/or iterables of values.
-    datasets : TinyDB
+    datasets : PickleableTinyDB
         Database of phase equilibria datasets
     eq_kwargs : dict
         Keyword arguments passed to pycalphad equilibrium()
@@ -230,12 +382,38 @@ def multiplot(dbf, comps, phases, conds, datasets, eq_kwargs=None, plot_kwargs=N
 
     eq_result = equilibrium(dbf, comps, phases, conds, **eq_kwargs)
     ax = eqplot(eq_result, **plot_kwargs)
-    ax = dataplot(eq_result, datasets, ax=ax, **data_kwargs)
+    ax = eqdataplot(eq_result, datasets, ax=ax, plot_kwargs=data_kwargs)
     return ax
 
 
-def _compare_data_to_parameters(dbf, comps, phase_name, desired_data, mod, configuration, x, y):
-    import matplotlib.pyplot as plt
+def _compare_data_to_parameters(dbf, comps, phase_name, desired_data, mod, configuration, x, y, ax=None):
+    """
+    Return one set of plotted Axes with data compared to calculated parameters
+
+    Parameters
+    ----------
+    dbf : Database
+        pycalphad thermodynamic database containing the relevant parameters.
+    comps : list
+        Names of components to consider in the calculation.
+    phase_name : str
+        Name of the considered phase phase
+    desired_data :
+    mod : Model
+        A pycalphad Model. The Model may or may not have the reference state zeroed out for formation properties.
+    configuration :
+    x : str
+        Model property to plot on the x-axis e.g. 'T', 'HM_MIX', 'SM_FORM'
+    y : str
+        Model property to plot on the y-axis e.g. 'T', 'HM_MIX', 'SM_FORM'
+    ax : matplotlib.Axes
+        Default axes used if not specified.
+
+    Returns
+    -------
+    matplotlib.Axes
+
+    """
     all_samples = np.array(get_samples(desired_data), dtype=np.object)
     endpoints = endmembers_from_interaction(configuration)
     interacting_subls = [c for c in list_to_tuple(configuration) if isinstance(c, tuple)]
@@ -245,7 +423,9 @@ def _compare_data_to_parameters(dbf, comps, phase_name, desired_data, mod, confi
         # In general this is a high-dimensional space; just plot the diagonal to see the disordered mixing
         endpoints = [endpoints[0], endpoints[-1]]
         disordered_config = True
-    fig = plt.figure(figsize=(9, 9))
+    if not ax:
+        fig = plt.figure(figsize=plt.figaspect(1))
+        ax = fig.gca()
     bar_chart = False
     bar_labels = []
     bar_data = []
@@ -277,10 +457,10 @@ def _compare_data_to_parameters(dbf, comps, phase_name, desired_data, mod, confi
                 extra_kwargs['marker'] = '.'
                 extra_kwargs['linestyle'] = 'none'
                 extra_kwargs['clip_on'] = False
-            fig.gca().plot(temperatures, response_data,
+            ax.plot(temperatures, response_data,
                            label='This work', color='k', **extra_kwargs)
-            fig.gca().set_xlabel(plot_mapping.get(x, x))
-            fig.gca().set_ylabel(plot_mapping.get(y, y))
+            ax.set_xlabel(plot_mapping.get(x, x))
+            ax.set_ylabel(plot_mapping.get(y, y))
         else:
             bar_labels.append('This work')
             bar_data.append(response_data[0])
@@ -302,17 +482,19 @@ def _compare_data_to_parameters(dbf, comps, phase_name, desired_data, mod, confi
                 extra_kwargs['marker'] = '.'
                 extra_kwargs['linestyle'] = 'none'
                 extra_kwargs['clip_on'] = False
-            fig.gca().plot(np.linspace(0, 1, num=100), response_data,
-                           label='This work', color='k', **extra_kwargs)
-            fig.gca().set_xlim((0, 1))
-            fig.gca().set_xlabel(str(':'.join(endpoints[0])) + ' to ' + str(':'.join(endpoints[1])))
-            fig.gca().set_ylabel(plot_mapping.get(y, y))
+            ax.plot(np.linspace(0, 1, num=100), response_data, label='This work', color='k', **extra_kwargs)
+            ax.set_xlim((0, 1))
+            ax.set_xlabel(str(':'.join(endpoints[0])) + ' to ' + str(':'.join(endpoints[1])))
+            ax.set_ylabel(plot_mapping.get(y, y))
         else:
             bar_labels.append('This work')
             bar_data.append(response_data[0])
     else:
         raise NotImplementedError('No support for plotting configuration {}'.format(configuration))
 
+    bib_reference_keys = sorted(list({entry['reference'] for entry in desired_data}))
+    symbol_map = bib_marker_map(bib_reference_keys)
+
     for data in desired_data:
         indep_var_data = None
         response_data = np.zeros_like(data['values'], dtype=np.float)
@@ -362,30 +544,33 @@ def _compare_data_to_parameters(dbf, comps, phase_name, desired_data, mod, confi
         if not bar_chart:
             extra_kwargs = {}
             if len(response_data) < 10:
-                extra_kwargs['markersize'] = 20
-                extra_kwargs['marker'] = '.'
+                extra_kwargs['markersize'] = 8
                 extra_kwargs['linestyle'] = 'none'
                 extra_kwargs['clip_on'] = False
-
-            fig.gca().plot(indep_var_data, response_data, label=data.get('reference', None),
-                           **extra_kwargs)
+            ref = data.get('reference', '')
+            mark = symbol_map[ref]['markers']
+            ax.plot(indep_var_data, response_data,
+                    label=symbol_map[ref]['formatted'],
+                    marker=mark['marker'],
+                    fillstyle=mark['fillstyle'],
+                    **extra_kwargs)
         else:
             bar_labels.append(data.get('reference', None))
             bar_data.append(response_data[0])
     if bar_chart:
-        fig.gca().barh(0.02 * np.arange(len(bar_data)), bar_data,
+        ax.barh(0.02 * np.arange(len(bar_data)), bar_data,
                        color='k', height=0.01)
         endmember_title = ' to '.join([':'.join(i) for i in endpoints])
-        fig.suptitle('{} (T = {} K)'.format(endmember_title, temperatures), fontsize=20)
-        fig.gca().set_yticks(0.02 * np.arange(len(bar_data)))
-        fig.gca().set_yticklabels(bar_labels, fontsize=20)
+        ax.get_figure().suptitle('{} (T = {} K)'.format(endmember_title, temperatures), fontsize=20)
+        ax.set_yticks(0.02 * np.arange(len(bar_data)))
+        ax.set_yticklabels(bar_labels, fontsize=20)
         # This bar chart is rotated 90 degrees, so "y" is now x
-        fig.gca().set_xlabel(plot_mapping.get(y, y))
+        ax.set_xlabel(plot_mapping.get(y, y))
     else:
-        fig.gca().set_frame_on(False)
-        leg = fig.gca().legend(loc='best')
+        ax.set_frame_on(False)
+        leg = ax.legend(loc='best')
         leg.get_frame().set_edgecolor('black')
-    fig.canvas.draw()
+    return ax
 
 
 def _translate_endmember_to_array(endmember, variables):
